
#%%


#from jgtpy.JGTIDS import _ids_add_fdb_column_logics_v2
#from jgtpy import jgtapyhelper as th


#from jgtpy.JGTIDSSvc import get_ids
#from jgtpy.JGTIDSRequest import JGTIDSRequest
i="GBP/USD"
t="H1"

from jgtapp import ids

ids(i,t)

from jgtpy.JGTIDS
#df = get_ids(rq=JGTIDSRequest(i,t))
# %%
